summaryrefslogtreecommitdiffstats
path: root/Modules/FindMatlab.cmake
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2023-09-18 12:49:32 (GMT)
committerKitware Robot <kwrobot@kitware.com>2023-09-18 12:50:10 (GMT)
commitd007eb70468437cb7a1f30d160f3b97263cbc087 (patch)
treee11ea6f43ae8af4317c5163c4186f6ac266b157b /Modules/FindMatlab.cmake
parente64c150b3fe44117600b136ec5fbaff1774c3a0a (diff)
parentcf7ea12a7e3b6d47c301b435d90abef03d88e7cc (diff)
downloadCMake-d007eb70468437cb7a1f30d160f3b97263cbc087.zip
CMake-d007eb70468437cb7a1f30d160f3b97263cbc087.tar.gz
CMake-d007eb70468437cb7a1f30d160f3b97263cbc087.tar.bz2
Merge topic 'FindMatlab-r2023b'
cf7ea12a7e FindMatlab: Add R2023b=23.2 Acked-by: Kitware Robot <kwrobot@kitware.com> Merge-request: !8804
Diffstat (limited to 'Modules/FindMatlab.cmake')
-rw-r--r--Modules/FindMatlab.cmake15
1 files changed, 8 insertions, 7 deletions
diff --git a/Modules/FindMatlab.cmake b/Modules/FindMatlab.cmake
index fcd30ff..82350bb 100644
--- a/Modules/FindMatlab.cmake
+++ b/Modules/FindMatlab.cmake
@@ -140,8 +140,8 @@ Result variables
``Matlab_VERSION``
.. versionadded:: 3.27
- the numerical version (e.g. 9.13) of Matlab found. Not to be confused with
- Matlab release name (e.g. R2022b) that can be obtained with
+ the numerical version (e.g. 23.2.0) of Matlab found. Not to be confused with
+ Matlab release name (e.g. R2023b) that can be obtained with
:command:`matlab_get_release_name_from_version`.
``Matlab_ROOT_DIR``
the final root of the Matlab installation determined by the FindMatlab
@@ -302,6 +302,7 @@ if(NOT MATLAB_ADDITIONAL_VERSIONS)
endif()
set(MATLAB_VERSIONS_MAPPING
+ "R2023b=23.2"
"R2023a=9.14"
"R2022b=9.13"
"R2022a=9.12"
@@ -345,8 +346,8 @@ file(MAKE_DIRECTORY "${_matlab_temporary_folder}")
matlab_get_version_from_release_name(release version)
* Input: ``release`` is the release name (R2022b)
* Output: ``version`` is the version of Matlab (9.13)
Returns the version of Matlab from a release name
#]=======================================================================]
@@ -372,8 +373,8 @@ endmacro()
matlab_get_release_name_from_version(version release_name)
* Input: ``version`` is the version of Matlab (9.13)
* Output: ``release_name`` is the release name (R2022b)
Returns the release name from the version of Matlab
#]=======================================================================]
@@ -1412,7 +1413,7 @@ function(_Matlab_VersionInfoXML)
file(READ ${_XMLfile} versioninfo_string)
if(versioninfo_string)
- # parses "<version>9.2.0.538062</version>"
+ # parses "<version>23.2.0.2365128</version>"
string(REGEX MATCH "<version>(.*)</version>"
version_reg_match
${versioninfo_string}
@@ -345,8 +346,8 @@ file(MAKE_DIRECTORY "${_matlab_temporary_folder}")
matlab_get_version_from_release_name(release version)
- * Input: ``release`` is the release name (R2022b)
- * Output: ``version`` is the version of Matlab (9.13)
+ * Input: ``release`` is the release name (e.g. R2023b)
+ * Output: ``version`` is the version of Matlab (e.g. 23.2.0)
Returns the version of Matlab from a release name
#]=======================================================================]
@@ -372,8 +373,8 @@ endmacro()
matlab_get_release_name_from_version(version release_name)
- * Input: ``version`` is the version of Matlab (9.13)
- * Output: ``release_name`` is the release name (R2022b)
+ * Input: ``version`` is the version of Matlab (e.g. 23.2.0)
+ * Output: ``release_name`` is the release name (R2023b)
Returns the release name from the version of Matlab
#]=======================================================================]